uhugo.install — uHugo 1.1.10 documentation

# uhugo.install

uhugo.install.install_hugo(extract_from: str, os_type: str = 'Linux', move_to: str = '/home/akshay/bin') → str

  Installs the `hugo` binary at a given path

  Parameters:

    - extract_from – The path zip/tar file downloaded

    - os_type – Type of OS - `Windows`, `Darwin` or `posix`.

    - move_to – Instillation location. Defaults to `bin_folder()`

  Returns:

    Installation path